@@ -1,4 +1,5 @@
-#!/usr/bin/python2.6
+#!/usr/bin/env python
+#
 # @package      hubzero-submit-server
 # @file         submit-server.py
 # @author       Steven Clark <clarks@purdue.edu>
@@ -30,7 +31,7 @@
 import os
 import sys
 
-from hubzero.submit.LogMessage   import openLog, logJobId as log
+from hubzero.submit.LogMessage   import getLogMessageFileNo, openLog, logID as log
 from hubzero.submit.SubmitServer import SubmitServer
 
 LOGDIRECTORY = os.path.join(os.sep,'var','log','submit')
@@ -44,8 +45,19 @@ CONFIGFILEPATH         = os.path.join(CONFIGURATIONDIRECTORY,CONFIGURATIONFILE)
 
 DISTRIBUTORDIRECTORY = os.path.join(os.sep,'opt','submit')
 DISTRIBUTORSCRIPT    = 'distributor'
+JOBSTATUSDIRECTORY   = os.path.join(os.sep,'opt','submit')
+JOBSTATUSSCRIPT      = 'jobStatus.py'
+JOBKILLDIRECTORY     = os.path.join(os.sep,'opt','submit')
+JOBKILLSCRIPT        = 'jobKill.py'
 
 def daemonize():
+   logMessageFileNo = getLogMessageFileNo()
+   if logMessageFileNo != sys.stdout.fileno():
+      devnull = open("/dev/null",'r')
+      os.dup2(devnull.fileno(),sys.stdin.fileno())
+      os.dup2(logMessageFileNo,sys.stdout.fileno())
+      os.dup2(logMessageFileNo,sys.stderr.fileno())
+
    if os.fork():
       os._exit(os.EX_OK)
    os.setsid()
@@ -72,13 +84,18 @@ def writePidFile(pidFile):
       os._exit(os.EX_CANTCREAT)
 
 
-def server(distributorDirectory,
+def server(configFilePath,
+           distributorDirectory,
            distributorScript,
-           configFilePath):
-   submitServer = SubmitServer(distributorDirectory,distributorScript)
-   if submitServer.configure(configFilePath):
+           jobStatusDirectory,jobStatusScript,
+           jobKillDirectory,jobKillScript):
+   submitServer = SubmitServer(configFilePath,
+                               distributorDirectory,distributorScript,
+                               jobStatusDirectory,jobStatusScript,
+                               jobKillDirectory,jobKillScript)
+   if submitServer.configure():
       if submitServer.setupMySQL():
-         if submitServer.setupListeners():
+         if submitServer.setupClientListeners():
             submitServer.run()
          else:
             log("Shutting down - no listeners configured.")
@@ -98,7 +115,11 @@ if __name__ == '__main__':
 
    writePidFile(PIDFILE)
 
-   server(DISTRIBUTORDIRECTORY,DISTRIBUTORSCRIPT,CONFIGFILEPATH)
+   server(CONFIGFILEPATH,
+          DISTRIBUTORDIRECTORY,DISTRIBUTORSCRIPT,
+          JOBSTATUSDIRECTORY,JOBSTATUSSCRIPT,
+          JOBKILLDIRECTORY,JOBKILLSCRIPT)
 
    sys.exit(0)
-   
+
+
